
#import "../libs/AppleTV.js"

// --------------------------------------------------------------------------------
//      Object: hbogo
//              hbogo is an ATVAApp object for interacting with the
//              HBO GO appliance on Apple TV.
// --------------------------------------------------------------------------------

if (typeof hbogo == 'undefined') {
    hbogo = new ATVAApp("HBO GO");
}

if (typeof hbogo != 'undefined') {
    hbogo._objectName = "hbogo";

    hbogo.isErrorPage = function isErrorPage() {
        appletv.dismissScreenSaver();

        var theElements = appletv.mainWindow().elements().toArray();
        if ( ! theElements) {
            // No elements on screen to check, assuming loading
            return(false);
        }
        else if (theElements.length <= 2) {
            // loading pages will have one or two elements
            var theName = undefined;
            for (var i = 0; i < theElements.length; ++i) {
                if (theElements[i].attributes().class == "UIAElement") {
                    theName = theElements[i].name();
                }
                else if (theElements[i].attributes().class == "UIAImage") {
                    // ignore
                }
                else {
                    // don't know this pattern
                    UIALogger.logError("Don't know this pattern.");
                    appletv.mainWindow().logElementTree();
                    return(true);
                }
            }

            if ( ! theName) {
                // no UIAElement yet, loading
                return(false);
            }
            else if (theName && (theName == "Screen Saver")) {
                UIALogger.logError("Screen Saver is running on top of page access.");
                return(false);
            }
            else if (theName && (theName == "Accessing Qello")) {
                // Loading
                return(false);
            }
            else {
                UIALogger.logError("Qello error page.");
                UIALogger.logError(theName);
                return(true);
            }
        }
        else if (ATVAPageMainMenu.isMainMenuDisplayed()) {
            UIALogger.logError("Popped back to main menu.");
            return(true);
        }
        return(false);
    }

    hbogo.isLoadingPage = function isLoadingPage() {
        appletv.dismissScreenSaver();

        var theElements = appletv.mainWindow().elements().toArray();
        if ( ! theElements) {
            // No elements on screen to check, assuming loading
            return(true);
        }
        else if (theElements.length <= 2) {
            // loading pages will have one or two elements
            var theName = undefined;
            for (var i = 0; i < theElements.length; ++i) {
                if (theElements[i].attributes().class == "UIAElement") {
                    theName = theElements[i].name();
                }
                else if (theElements[i].attributes().class == "UIAImage") {
                    // ignore
                }
                else {
                    // don't know this pattern
                    UIALogger.logError("Don't know this pattern.");
                    appletv.mainWindow().logElementTree();
                    return(false);
                }
            }

            if ( ! theName) {
                // no UIAElement yet, loading
                return(true);
            }
            else if (theName && (theName == "Screen Saver")) {
                UIALogger.logError("Screen Saver is running on top of page access.");
                return(false);
            }
            else if (theName && (theName == "Accessing Qello")) {
                // Loading
                return(true);
            }
            else {
                UIALogger.logError("Qello error page.");
                UIALogger.logError(theName);
                return(false);
            }
        }
        // not a loading page
        return(false);
    }

    // overriding fromMenu() method from base ATVAApp()
    hbogo.fromMenu = function fromMenu() {
        var menu = new ATVAPageStore(this._title);
        if ( ! menu.waitForPage()) {
            UIALogger.logError(this._objectName + ".fromMenu(): failed to waiting for " + this._title);
            return(undefined);
        }
        return(menu);
    }

    // --------------------------------------------------------------------------------
    //      Function: searchForMovie
    //              Go to the Netflix > Search and search for movie.
    //      Parameters:
    //              movieTitle - string
    //      Returns:
    //              true  - Found item and selected it.
    //              false - Failed to get to item
    // --------------------------------------------------------------------------------
    hbogo.searchForMovie = function searchForMovie(movieTitle) {
        if (this.goToAndSelect("Search")) {
            // enter movieTitle
            var skb = new ATVAPageSearch("Search");
            if ( ! skb.waitForPage()) {
                UIALogger.logError(this._objectName + ".searchForMovie(): failed waiting for Search");
                return (undefined);
            }
            if ( ! skb.enterString(movieTitle)) {
                UIALogger.logError(this._objectName + ".searchForMovie(): failed entering string for Search");
                return (undefined);
            }
            if ( ! skb.moveToSearch(movieTitle)) {
                if ( ! skb.moveToSearch(movieTitle + ", HD content")) {
                    UIALogger.logError(this._objectName + ".searchForMovie(): search item was not returned");
                    return (undefined);
                }
            }
            // Got to item
            skb.selectIntoPage();

            var dp = new ATVAPageVideoDetail(movieTitle);
            if ( ! dp.waitForPage()) {
                UIALogger.logError(this._objectName + ".searchForMovie(): failed to load movies detail page for " + movieTitle);
                return (undefined);
            }

            return (dp);
        }

        UIALogger.logError(this._objectName + ".searchForMovie(): failed selecting Search");
        return(undefined);
    }

    hbogo.searchAndPlayMovie = function searchAndPlayMovie(movieTitle, shouldResume) {
        var dp = this.searchForMovie(movieTitle);

        if ( ! dp) {
            UIALogger.logError(this._objectName + ".searchAndPlayMovie(): failed to load movies detail page for " + movieTitle);
            return(undefined);
        }

        if ( ! dp.play(shouldResume)) {
            UIALogger.logError(this._objectName + ".searchAndPlayMovie(): failed to play " + movieTitle);
            return(undefined);
        }

        return(dp);
    }

    hbogo.searchAndPlayMovieWaitForEnd = function searchAndPlayMovieWaitForEnd(movieTitle, shouldResume) {
        var dp = this.searchForMovie(movieTitle);

        if ( ! dp) {
            UIALogger.logError(this._objectName + ".searchAndPlayMovieWaitForEnd(): failed to load movies detail page for " + movieTitle);
            return(undefined);
        }

        if ( ! dp.playAndWaitForEnd(shouldResume)) {
            UIALogger.logError(this._objectName + ".searchAndPlayMovieWaitForEnd(): failed to playing " + movieTitle);
            return(undefined);
        }

        return(dp);
    }
}
