
#import "HBOGo.js"

/**
 *       Function: hbogoTest_searchForMovie
 *           Search for movie through HBO GO>Search.
 *   
 *  \param movieTitle (string) - movie title
 *   
 *  \return 1 if found, otherwise 0
 **/

function hbogoTest_searchForMovie() {
    if (this.argv.length < 1) {
        this.testError = "No movie title supplied.";
        return this.testResult = 0;
    }
    var movieTitle = this.argv[0];
    if ( ! hbogo.searchForMovie(movieTitle)) {
        this.testError = "Fail to search for movie";
        return this.testResult = 0;
    }
    else {
        return this.testResult = 1;
    }
}

/**
 *       Function: hbogoTest_searchForMovieAndPlay
 *           Search for movie through HBO GO>Search, play movie from beginning and wait for it to complete.
 *   
 *  \param movieTitle (string) - movie title
 *  \param returnToMainMenu (string) - if this argument is given, no matter what, we return to the Main Menu>Settings at the end
 *   
 *  \return 1 if movie played, otherwise 0
 **/

function hbogoTest_searchForMovieAndPlay() {
    if (this.argv.length < 1) {
        this.testError = "No timeout supplied.";
        return this.testResult = 0;
    }
    var movieTitle = this.argv[0];
    var returnToMainMenu = false;
    if (this.argv.length >= 2) {
        returnToMainMenu = true;
    }
    if ( ! hbogo.searchAndPlayMovieWaitForEnd(movieTitle, false)) {
        if (returnToMainMenu) {
            ATVAPageMainMenu.goToAndSelect("Settings");
        }
        this.testError = "Fail to search for and play movie";
        return this.testResult = 0;
    }
    else {
        if (returnToMainMenu) {
            ATVAPageMainMenu.goToAndSelect("Settings");
        }
        return this.testResult = 1;
    }
}

/**
 *       Function: hbogoTest_searchForMovieAndPlayFor
 *           Search for movie through HBO GO>Search, play movie from beginning for the specified number of seconds.
 *           Notice that the time to play starts after the movie begins playback and does not include caching.
 *   
 *  \param movieTitle (string) - movie title
 *  \param secondsToPlay (number) - seconds to play movie.
 *   
 *  \return 1 if movie played, otherwise 0
 **/

function hbogoTest_searchForMovieAndPlayFor() {
    if (this.argv.length < 2) {
        this.testError = "movie title and time to play must be specified";
        return this.testResult = 0;
    }
    var movieTitle = this.argv[0];
    var secondsToPlay = this.argv[1];

    var dp = hbogo.searchAndPlayMovie(movieTitle, false);

    if ( ! dp) {
        this.testError = "Fail to search for and play movie";
        return this.testResult = 0;
    }
    else {
        atvaTarget.delay(secondsToPlay);
        dp.dismissScreenSaver();
        dp.menuOutOfPage();
        return this.testResult = 1;
    }
}

/**
 *       Function: hbogoTest_searchForMovieAndPlayAndPauseFor
 *           Search for movie through HBO GO>Search, play movie from beginning. After playback starts, pause for
 *           secondsToPause. Notice that the time to pause starts after the movie begins playback and does not
 *           include caching.
 *   
 *  \param movieTitle (string) - movie title
 *  \param secondsToPause (number) - seconds to play movie.
 *   
 *  \return 1 if movie played, otherwise 0
 **/

function hbogoTest_searchForMovieAndPlayAndPauseFor() {
    if (this.argv.length < 2) {
        this.testError = "movie title and time to pause must be specified";
        return this.testResult = 0;
    }
    var movieTitle = this.argv[0];
    var secondsToPause = this.argv[1];

    var dp = hbogo.searchAndPlayMovie(movieTitle, false);

    if ( ! dp) {
        this.testError = "Fail to search for and play movie";
        return this.testResult = 0;
    }
    else {
        dp.buttonSelect();
        atvaTarget.delay(secondsToPause);
        dp.dismissScreenSaver();
        dp.menuOutOfPage();
        return this.testResult = 1;
    }
}

