
function ATVAOutput(outputDirectory) {
    // If outputDirectory is specified, then it is intended to append to information there
    if (typeof outputDirectory == 'undefined') {
        this._outputDirectory = "/var/root/" + ATVAOutput.fileTimeStamp() + "_OUTPUT";
        ATVAOutput.makeDirectory(this._outputDirectory);
    }
    else {
        this._outputDirectory = outputDirectory;
        ATVAOutput.makeDirectory(this._outputDirectory);
    }

    this.nextIndexString = function nextIndexString(index) {
        var indexString;
        if (index < 10) {
            indexString = "000" + index;
        }
        else if (index < 100) {
            indexString = "00" + index;
        }
        else if (index < 1000) {
            indexString = "0" + index;
        }
        else {
            indexString = "" + index;
        }
        return(indexString);
    }

    // Processes to take heaps
    this._heapCommand = undefined;
    this._heapProcesses = new Array();
    this.addHeapProcess = function addHeapProcess(process) {
        this._heapProcesses.push(process);
        // create directory if needed
        ATVAOutput.makeDirectory(this._outputDirectory + "/" + process + ".heaps");

        var fd = undefined;
        try {
            fd = new File(this._outputDirectory + "/" + process + ".heaps/info.json", "r");
        }
        catch (e) {
            // ignoring
        }

        var info;
        if ( ! fd) {
            // info.json does not exist, create it
            info = {heapIteration:0};
            UIALogger.logMessage("Creating " + this._outputDirectory + "/" + process + ".heaps/info.json");
            fd = new File(this._outputDirectory + "/" + process + ".heaps/info.json", "w");
            fd.write(JSON.stringify(info));
        }
        else {
            info = JSON.parse(fd.read());
            if ( ! info) {
                info = {heapIteration:0};
            }
            if ( ! ("heapIteration" in info)) {
                // need to added heapIteration to info
                info["heapIteration"] = 0;
                fd = new File(this._outputDirectory + "/" + process + ".heaps/info.json", "w");
                fd.write(JSON.stringify(info));
            }
        }
    }

    this.createHeapCommand = function createHeapCommand() {
        this._heapCommand = "/tmp/heapCommand";

        system.run("/bin/rm -f " + this._heapCommand, Number.MAX_VALUE);

        var fd = new File(this._heapCommand, "w");
        fd.write("#! /bin/bash\n");
        fd.write("process=\"$1\"\n");
        fd.write("file=\"$2\"\n");
        fd.write("/usr/bin/heap -noContent -addresses only \"$process\" > \"$file\"\n");
        fd.write("echo Done\n");
    }

    this.collectProcessInfomation = function collectProcessInfomation(message) {
        if (typeof message == 'undefined') {
            message = "Start";
        }

        if ( ! this._heapCommand) {
            this.createHeapCommand();
        }

        for (var i = 0; i < this._heapProcesses.length; ++i) {
            var process = this._heapProcesses[i];

            // load iteration information
            var fd = new File(this._outputDirectory + "/" + process + ".heaps/info.json", "r");
            var info = JSON.parse(fd.read());
            var currentIteration = info["heapIteration"];

            var outputFile = this._outputDirectory + "/" + process + ".heaps/" + process + "###" + this.nextIndexString(currentIteration) + "###" + ".heap";
            var messageFile = this._outputDirectory + "/" + process + ".heaps/messages.log";

            system.run("/bin/bash " + this._heapCommand + " " + process + " " + outputFile, Number.MAX_VALUE);

            var messageFD = new File(messageFile, "a");
            messageFD.write("msg\t" + this.nextIndexString(currentIteration) + "\t" + ATVAOutput.absTime() + "\t" + message + "\n");

            // update iteration information
            info["heapIteration"] = currentIteration + 1;
            fd = new File(this._outputDirectory + "/" + process + ".heaps/info.json", "w");
            fd.write(JSON.stringify(info));
        }
    }

    this.createScreenCaptureDirectory = function createScreenCaptureDirectory() {
        // create directory if needed
        ATVAOutput.makeDirectory(this._outputDirectory + "/screenCapture");

        var fd = undefined;
        try {
            fd = new File(this._outputDirectory + "/screenCapture/info.json", "r");
        }
        catch (e) {
            // ignoring
        }

        var info;
        if ( ! fd) {
            // info.json does not exist, create it
            info = {screenCaptureIteration:0};
            UIALogger.logMessage("Creating " + this._outputDirectory + "/screenCapture/info.json");
            fd = new File(this._outputDirectory + "/screenCapture/info.json", "w");
            fd.write(JSON.stringify(info));
        }
        else {
            info = JSON.parse(fd.read());
            if ( ! info) {
                info = {screenCaptureIteration:0};
            }
            if ( ! ("screenCaptureIteration" in info)) {
                // need to added screenCaptureIteration to info
                info["screenCaptureIteration"] = 0;
                fd = new File(this._outputDirectory + "/screenCapture/info.json", "w");
                fd.write(JSON.stringify(info));
            }
        }
    }

    this.takeScreenCapture = function takeScreenCapture() {
        this.createScreenCaptureDirectory();

        // load iteration information
        var fd = new File(this._outputDirectory + "/screenCapture/info.json", "r");
        var info = JSON.parse(fd.read());
        var currentIteration = info["screenCaptureIteration"];

        var screenCaptureFile = this._outputDirectory + "/screenCapture/screencapture" + "###" + this.nextIndexString(currentIteration) + "###" + ".png";
        system.captureScreen(screenCaptureFile);

        // update iteration information
        info["screenCaptureIteration"] = currentIteration + 1;
        fd = new File(this._outputDirectory + "/screenCapture/info.json", "w");
        fd.write(JSON.stringify(info));
    }

    return(this);
}

ATVAOutput.absTime = function absTime() {
    var old2001 = new Date(2001, 1, 1, 0, 0, 0, 0);
    var now = new Date();
    return( (now - old2001.getTime())/1000.0 );
}

ATVAOutput.fileTimeStamp = function fileTimeStamp() {
    return(system.run("/bin/date \"+%Y%m%d_%H%M%S\"", Number.MAX_VALUE).stdout.split('\n')[0]);
}

ATVAOutput.makeDirectory = function makeDirectory(directory) {
    system.run("/bin/mkdir -p \"" + directory + "\"", Number.MAX_VALUE);
}
