
#import "../libs/AppleTV.js"

// --------------------------------------------------------------------------------
//      Object: qello
//              qello is an ATVAApp object for interacting with the
//              Qello appliance on Apple TV.
// --------------------------------------------------------------------------------

if (typeof qello == 'undefined') {
    qello = new ATVAApp("Qello");
}

if (typeof qello != 'undefined') {
    qello._objectName = "qello";

    // TODO: If Netflix is too slow, these can fail (haven't seen very often)
    qello.isAlreadyAMemberDisplayed = function isAlreadyAMemberDisplayed() {
        // need to use appletv object, instead of 'this' incase called without object.
        return(appletv.mainWindow().buttons()["Already have a Qello account? Sign In."].isValid());
    }

    qello.isQelloMainMenuDisplayed = function isQelloMainMenuDisplayed() {
        // need to use appletv object, instead of 'this' incase called without object.
        return(appletv.mainWindow().staticTexts()["Settings"].isValid() && appletv.mainWindow().staticTexts()["Search"].isValid());
    }

    qello.isErrorPage = function isErrorPage() {
        appletv.dismissScreenSaver();

        var theElements = appletv.mainWindow().elements().toArray();
        if ( ! theElements) {
            // No elements on screen to check, assuming loading
            return(false);
        }
        else if (theElements.length <= 2) {
            // loading pages will have one or two elements
            var theName = undefined;
            for (var i = 0; i < theElements.length; ++i) {
                if (theElements[i].attributes().class == "UIAElement") {
                    theName = theElements[i].name();
                }
                else if (theElements[i].attributes().class == "UIAImage") {
                    // ignore
                }
                else {
                    // don't know this pattern
                    UIALogger.logError("Don't know this pattern.");
                    appletv.mainWindow().logElementTree();
                    return(true);
                }
            }

            if ( ! theName) {
                // no UIAElement yet, loading
                return(false);
            }
            else if (theName && (theName == "Screen Saver")) {
                UIALogger.logError("Screen Saver is running on top of page access.");
                return(false);
            }
            else if (theName && (theName == "Accessing Qello")) {
                // Loading
                return(false);
            }
            else {
                UIALogger.logError("Qello error page.");
                UIALogger.logError(theName);
                return(true);
            }
        }
        else if (ATVAPageMainMenu.isMainMenuDisplayed()) {
            UIALogger.logError("Popped back to main menu.");
            return(true);
        }
        return(false);
    }

    qello.isLoadingPage = function isLoadingPage() {
        appletv.dismissScreenSaver();

        var theElements = appletv.mainWindow().elements().toArray();
        if ( ! theElements) {
            // No elements on screen to check, assuming loading
            return(true);
        }
        else if (theElements.length <= 2) {
            // loading pages will have one or two elements
            var theName = undefined;
            for (var i = 0; i < theElements.length; ++i) {
                if (theElements[i].attributes().class == "UIAElement") {
                    theName = theElements[i].name();
                }
                else if (theElements[i].attributes().class == "UIAImage") {
                    // ignore
                }
                else {
                    // don't know this pattern
                    UIALogger.logError("Don't know this pattern.");
                    appletv.mainWindow().logElementTree();
                    return(false);
                }
            }

            if ( ! theName) {
                // no UIAElement yet, loading
                return(true);
            }
            else if (theName && (theName == "Screen Saver")) {
                UIALogger.logError("Screen Saver is running on top of page access.");
                return(false);
            }
            else if (theName && (theName == "Accessing Qello")) {
                // Loading
                return(true);
            }
            else {
                UIALogger.logError("Qello error page.");
                UIALogger.logError(theName);
                return(false);
            }
        }
        // not a loading page
        return(false);
    }

    // overriding fromMenu() method from base ATVAApp()
    qello.fromMenu = function fromMenu() {
        var menu = new ATVAPageStore(this._title);
        if ( ! menu.waitForPage()) {
            UIALogger.logError(this._objectName + ".fromMenu(): failed to waiting for " + this._title);
            return(undefined);
        }
        return(menu);
    }

    // --------------------------------------------------------------------------------
    //      Function: enterAccountAndPassword
    //              Assumes that the account screen is about to be displayed. Enters
    //              account and password and answers the save password dialog.
    //      Parameters:
    //              account - string
    //              password - string
    //      Returns:
    //              true  - Found item and selected it.
    //              false - Failed to get to item
    // --------------------------------------------------------------------------------
    qello.enterAccountAndPassword = function enterAccountAndPassword(account, password) {
        // enter account, notice that Netflix doesn't have a title, depending on the keyboard
        var akb = new ATVAPageAccount("");
        if ( ! akb.waitForPage()) {
            UIALogger.logError(this._objectName + ".enterAccountAndPassword(): failed waiting for Account Entry Page");
            return (false);
        }
        if ( ! akb.enterString(account)) {
            UIALogger.logError(this._objectName + ".enterAccountAndPassword(): failed entering string on Account Entry Page");
            return (false);
        }
        if ( ! akb.submit()) {
            UIALogger.logError(this._objectName + ".enterAccountAndPassword(): failed to select Submit on Account Entry Page");
            return (false);
        }

        // enter password, notice no title, depending on the keyboard
        var pkb = new ATVAPageAccount("");
        if ( ! pkb.waitForPage()) {
            UIALogger.logError(this._objectName + ".enterAccountAndPassword(): failed waiting for Password Entry Page");
            return (false);
        }
        if ( ! pkb.enterString(password)) {
            UIALogger.logError(this._objectName + ".enterAccountAndPassword(): failed entering string on Password Entry Page");
            return (false);
        }
        if ( ! pkb.submit()) {
            UIALogger.logError(this._objectName + ".enterAccountAndPassword(): failed to select Submit on Password Entry Page");
            return (false);
        }

        return(true);
    }

    // --------------------------------------------------------------------------------
    //      Function: goToAlreadyAMemberAndLogin
    //              Go to the Netflix "Already a Member?" dialog is displayed and 
    //              logs in with account and password.
    //      Parameters:
    //              account - string
    //              password - string
    //      Returns:
    //              true  - Found item and selected it.
    //              false - Failed to get to item
    // --------------------------------------------------------------------------------
    qello.goToAlreadyAMemberAndLogin = function goToAlreadyAMemberAndLogin(account, password) {
        if (ATVAPageMainMenu.goToAndSelect(this._title)) {
            var alreadyAMemberMenu = new ATVAPage("Already A Memeber");
            alreadyAMemberMenu.isPageDisplayed = this.isAlreadyAMemberDisplayed;

            var qelloMainMenu = new ATVAPageStore(this._title);

            var pages = new Array(alreadyAMemberMenu, qelloMainMenu);
            if ( ! ATVAPage.waitForOneOfThesePages(pages, 5, 60)) {
                UIALogger.logError(this._objectName + ".goToAlreadyAMemberAndLogin(): failed find either Qello login or main menu");
                return (false);
            }

            if (alreadyAMemberMenu.isPageDisplayed()) {
                // Got the login screen, lets login.
                if ( ! alreadyAMemberMenu.moveToItemWithNameAndSelect("Already have a Qello account? Sign In.")) {
                    UIALogger.logError(this._objectName + ".goToAlreadyAMemberAndLogin(): failed to select Already a subscriber");
                    return(false);
                }

                if ( ! this.enterAccountAndPassword(account, password)) {
                    UIALogger.logError(this._objectName + ".goToAlreadyAMemberAndLogin(): failed to enter account and password");
                    return(false);
                }
            }

            if ( ! qelloMainMenu.waitForPage()) {
                UIALogger.logError(this._objectName + ".goToAlreadyAMemberAndLogin(): failed waiting for Qello main menu");
                return(false);
            }

            return(true);
        }

        UIALogger.logError(this._objectName + ".goToAlreadyAMemberAndLogin(): failed selecting Qello");
        return(false);
    }

    // --------------------------------------------------------------------------------
    //      Function: goToAndSignOut
    //              Go to the Netflix and select Sign Out
    //      Returns:
    //              true  - Found item and selected it.
    //              false - Failed to get to item
    // --------------------------------------------------------------------------------
    qello.goToAndSignOut = function goToAndSignOut() {
        if (this.goToAndSelect("Sign Out")) {
            var menu = new ATVAPage("Are you sure?");
            if ( ! menu.waitForPage()) {
                UIALogger.logError(this._objectName + ".goToAndSignOut(): failed waiting for Sign Out confirmation");
                return(false);
            }
            if ( ! menu.moveToItemWithNameAndSelect("Yes")) {
                UIALogger.logError(this._objectName + ".goToAndSignOut(): failed selecting Yes on Sign Out confirmation");
                return(false);
            }

            return(true);
        }

        UIALogger.logError(this._objectName + ".goToAndSignOut(): failed selecting Sign Out");
        return(false);
    }

    // --------------------------------------------------------------------------------
    //      Function: searchForMovie
    //              Go to the Netflix > Search and search for movie.
    //      Parameters:
    //              movieTitle - string
    //      Returns:
    //              true  - Found item and selected it.
    //              false - Failed to get to item
    // --------------------------------------------------------------------------------
    qello.searchForMovie = function searchForMovie(movieTitle) {
        if (this.goToAndSelect("Search")) {
            // enter movieTitle
            var skb = new ATVAPageSearch("Search");
            if ( ! skb.waitForPage()) {
                UIALogger.logError(this._objectName + ".searchForMovie(): failed waiting for Search");
                return (undefined);
            }
            if ( ! skb.enterString(movieTitle)) {
                UIALogger.logError(this._objectName + ".searchForMovie(): failed entering string for Search");
                return (undefined);
            }
            if ( ! skb.moveToSearch(movieTitle)) {
                if ( ! skb.moveToSearch(movieTitle + ", HD content")) {
                    UIALogger.logError(this._objectName + ".searchForMovie(): search item was not returned");
                    return (undefined);
                }
            }
            // Got to item
            skb.selectIntoPage();

            var dp = new ATVAPageVideoDetail(movieTitle);
            dp.setVideoType(ATVAPageVideoDetail.NETFLIXTYPE);
            if ( ! dp.waitForPage()) {
                UIALogger.logError(this._objectName + ".searchForMovie(): failed to load movies detail page for " + movieTitle);
                return (undefined);
            }

            return (dp);
        }

        UIALogger.logError(this._objectName + ".searchForMovie(): failed selecting Search");
        return(undefined);
    }

    qello.searchAndPlayMovie = function searchAndPlayMovie(movieTitle, shouldResume) {
        var dp = this.searchForMovie(movieTitle);

        if ( ! dp) {
            UIALogger.logError(this._objectName + ".searchAndPlayMovie(): failed to load movies detail page for " + movieTitle);
            return(undefined);
        }

        if ( ! dp.play(shouldResume)) {
            UIALogger.logError(this._objectName + ".searchAndPlayMovie(): failed to play " + movieTitle);
            return(undefined);
        }

        return(dp);
    }

    qello.searchAndPlayMovieWaitForEnd = function searchAndPlayMovieWaitForEnd(movieTitle, shouldResume) {
        var dp = this.searchForMovie(movieTitle);

        if ( ! dp) {
            UIALogger.logError(this._objectName + ".searchAndPlayMovieWaitForEnd(): failed to load movies detail page for " + movieTitle);
            return(undefined);
        }

        if ( ! dp.playAndWaitForEnd(shouldResume)) {
            UIALogger.logError(this._objectName + ".searchAndPlayMovieWaitForEnd(): failed to playing " + movieTitle);
            return(undefined);
        }

        return(dp);
    }
}
