
#import "../Settings.js"

// --------------------------------------------------------------------------------
//      Object: itunesstore
//              itunesstore is an ATVAApp object for interacting with the
//              iTunes Store appliance on Apple TV.
// --------------------------------------------------------------------------------

if (typeof itunesstore == 'undefined') {
    itunesstore = new ATVAApp("iTunes Store");
}

if (typeof itunesstore != 'undefined') {
    itunesstore._objectName = "itunesstore";

    // overriding fromMenu(), and goTo() methods from base ATVAApp()
    itunesstore.fromMenu = function fromMenu() {
        var menu = new ATVAPageListMenu(this._title);
        if ( ! menu.waitForPage()) {
            UIALogger.logError(this._objectName + ".fromMenu(): failed to waiting for " + this._title);
            return(undefined);
        }
        return(menu);
    }

    itunesstore.goTo = function goTo() {
        if (settings.goToAndSelect(this._title)) {
            return(this.fromMenu());
        }
        UIALogger.logError(this._objectName + ".goTo(): failed to get to " + this._title);
        return(undefined);
    }

    // methods for Account

    // --------------------------------------------------------------------------------
    //      Function: enterAccountAndPassword
    //              Assumes that the account screen is about to be displayed. Enters
    //              account and password and answers the save password dialog.
    //      Parameters:
    //              account - string
    //              password - string
    //              rememberPassword - boolean
    //      Returns:
    //              true  - Found item and selected it.
    //              false - Failed to get to item
    // --------------------------------------------------------------------------------

    itunesstore.enterAccountAndPassword = function enterAccountAndPassword(account, password, rememberPassword) {
        // enter account
        var akb = new ATVAPageAccount("iTunes Store Sign-In");
        if ( ! akb.waitForPage()) {
            return (false);
        }
        if ( ! akb.enterString(account)) {
            return (false);
        }
        if ( ! akb.submit()) {
            return (false);
        }

        // enter password
        var pkb = new ATVAPageAccount("iTunes Store Password");
        if ( ! pkb.waitForPage()) {
            return (false);
        }
        if ( ! pkb.enterString(password)) {
            return (false);
        }
        if ( ! pkb.submit()) {
            return (false);
        }

        var savePasswordMenu = new ATVAPage("Remember Password?");
        if ( ! savePasswordMenu.waitForPage()) {
            return (false);
        }

        if (rememberPassword) {
            return (savePasswordMenu.moveToItemWithNameAndSelect("Yes"));
        }
        else {
            return (savePasswordMenu.moveToItemWithNameAndSelect("No"));
        }
    }

    // --------------------------------------------------------------------------------
    //      Function: loginAccount
    //              Go back to main menu select Settings>iTunes Store and then login
    //              to iTunes Store.
    //      Parameters:
    //              account - string
    //              password - string
    //              rememberPassword - boolean
    //      Returns:
    //              true  - Found item and selected it.
    //              false - Failed to get to item
    // --------------------------------------------------------------------------------

    itunesstore.loginAccount = function loginAccount(account, password, rememberPassword) {
        var menu = this.goTo();
        var focus;
        if ( ! menu) {
            return(false);
        }

        if (menu.moveToItemWithNameAndSelect("Sign In")) {
            // This is the first account to be entered.
            if (this.enterAccountAndPassword(account, password, rememberPassword)) {
                menu = this.fromMenu();
                if (menu) {
                    focus = menu.moveToItemWithName("Apple IDs");
                    if (focus) {
                        if (focus.value() == account) {
                            return(true);
                        }
                        return(false);
                    }
                    return(false);
                }
                return(false);
            }
            return(false);
        }
        else {
            // This isn't the first account.
            focus = menu.moveToItemWithName("Apple IDs");
            if ( ! focus) {
                return(false);
            }

            if (focus.value() == account) {
                // account already entered and selected.
                return(true);
            }
            menu.selectIntoPage();

            // in iTunes Store Accounts Page. Need List Menu because I don't know how many accounts

            var accountMenu = new ATVAPageListMenu("Apple IDs");
            if ( ! accountMenu.waitForPage()) {
                return (false);
            }

            if (accountMenu.moveToItemWithNameAndSelect(account)) {
                // account already entered, just select it
                UIALogger.logMessage("Found account and selected it");

                accountMenu = new ATVAPageListMenu("Apple IDs");
                if ( ! accountMenu.waitForPage()) {
                    return (false);
                }

                focus = accountMenu.moveToItemWithName("Sign Out");
                if ( ! focus) {
                    return(false);
                }
                if (focus.value() != account) {
                    return(false);
                }
                accountMenu.menuOutOfPage();

                menu = this.fromMenu();
                if (menu) {
                    focus = menu.moveToItemWithName("Apple IDs");
                    if (focus) {
                        if (focus.value() == account) {
                            return(true);
                        }
                        return(false);
                    }
                    return(false);
                }
                return (false);
            }
            else if (accountMenu.moveToItemWithNameAndSelect("Add New Apple ID")) {
                UIALogger.logMessage("Select Add New Apple ID");
                if (this.enterAccountAndPassword(account, password, rememberPassword)) {
                    accountMenu = new ATVAPageListMenu("Apple IDs");
                    if ( ! accountMenu.waitForPage()) {
                        return (false);
                    }

                    focus = accountMenu.moveToItemWithName("Sign Out");
                    if ( ! focus) {
                        return(false);
                    }
                    if (focus.value() != account) {
                        return(false);
                    }
                    accountMenu.menuOutOfPage();

                    menu = this.fromMenu();
                    if (menu) {
                        focus = menu.moveToItemWithName("Apple IDs");
                        if (focus) {
                            if (focus.value() == account) {
                                return(true);
                            }
                            return(false);
                        }
                        return(false);
                    }
                    return(false);
                }
                return(false);
            }
            return (false);
        }
        return(false);
    }

    // --------------------------------------------------------------------------------
    //      Function: loginAccount
    //              Go back to main menu select Settings>iTunes Store and then logout
    //              of iTunes Store.
    //              - If account is current account, then select Sign Out.
    //
    //      Parameters:
    //              account - string
    //      Returns:
    //              true  - Found item and selected it.
    //              false - Failed to get to item
    // --------------------------------------------------------------------------------

    itunesstore.logoutAccount = function loginAccount(account) {
        var menu = this.goTo();
        var focus;
        var accountIsCurrent = false;
        if ( ! menu) {
            return(false);
        }

        if (menu.moveToItemWithNameAndSelect("Sign In")) {
            // There are no accounts to sign out of.
            return(false);
        }
        else {
            // This is at least one account.
            focus = menu.moveToItemWithName("Apple IDs");
            if ( ! focus) {
                return(false);
            }

            if (focus.value() == account) {
                accountIsCurrent = true;
            }
            else {
                accountIsCurrent = false;
            }
            menu.selectIntoPage();

            // in iTunes Store Accounts Page. Need List Menu because I don't know how many accounts

            var accountMenu = new ATVAPageListMenu("Apple IDs");
            if ( ! accountMenu.waitForPage()) {
                return (false);
            }

            if ( accountIsCurrent ) {
                focus = accountMenu.moveToItemWithName("Sign Out");
                if ( ! focus ) {
                    // could get to "Sign Out"
                    return(false);
                }
                if (focus.value() != account) {
                    // account magically changed from the current to not the current
                    return(false);
                }
                accountMenu.selectIntoPage();

                // menu changed
                accountMenu = new ATVAPageListMenu("Apple IDs");
                if ( ! accountMenu.waitForPage()) {
                    return(false);
                }

                if (accountMenu.moveToItemWithName(account)) {
                    return(false)
                }

                accountMenu.menuOutOfPage();

                menu = this.fromMenu();
                if (menu) {
                    focus = menu.moveToItemWithName("Apple IDs");
                    if (focus) {
                        if (focus.value() == account) {
                            return(false);
                        }
                        return(true);
                    }
                    else if (menu.moveToItemWithName("Sign In")) {
                        return(true);
                    }
                    // there isn't a Accounts for Sign In.
                    return(false);
                }
                return (false);
            }
            else {
                if (accountMenu.moveToItemWithName(account)) {
                    accountMenu.buttonRight();

                    focus = accountMenu.itemWithFocus();
                    if ( ! focus) {
                        return(false);
                    }
                    if (focus.name() != "Remove Account") {
                        return(false);
                    }
                    accountMenu.selectIntoPage();

                    // menu changed
                    accountMenu = new ATVAPageListMenu("Apple IDs");
                    if ( ! accountMenu.waitForPage()) {
                        return(false);
                    }

                    if (accountMenu.moveToItemWithName(account)) {
                        return(false)
                    }

                    accountMenu.menuOutOfPage();

                    menu = this.fromMenu();
                    if (menu) {
                        focus = menu.moveToItemWithName("Apple IDs");
                        if (focus) {
                            if (focus.value() == account) {
                                return(false);
                            }
                            return(true);
                        }
                        else if (menu.moveToItemWithName("Sign In")) {
                            return(true);
                        }
                        // there isn't a Accounts for Sign In.
                        return(false);
                    }
                    return (false);
                }
                // couldn't find account
                return(false);
            }
        }
        return(false);
    }

    // --------------------------------------------------------------------------------
    //      Function: logoutAllAccounts
    //              Go back to main menu select Settings>iTunes Store and then logout
    //              of all iTunes Store accounts.
    //      Returns:
    //              true  - Found item and selected it.
    //              false - Failed to get to item
    // --------------------------------------------------------------------------------

    itunesstore.logoutAllAccounts = function logoutAllAccounts() {
        var menu = this.goTo();
        var focus;
        if ( ! menu) {
            return(false);
        }

        if (menu.moveToItemWithNameAndSelect("Sign In")) {
            // There are no accounts to sign out of.
            return(false);
        }
        else {
            // This is at least one account.
            focus = menu.moveToItemWithName("Apple IDs");
            if ( ! focus) {
                return(false);
            }
            menu.selectIntoPage();

            // in iTunes Store Accounts Page. Using a ATVAPage because we will be reloading
            // as we delete.

            var accountMenu = new ATVAPage("Apple IDs");
            if ( ! accountMenu.waitForPage()) {
                return (false);
            }

            while (accountMenu.moveToItemWithNameAndSelect("Remove Account")) {
                accountMenu = new ATVAPage("Apple IDs");
                if ( ! accountMenu.waitForPage()) {
                    return (false);
                }
            }
            accountMenu.menuOutOfPage();

            menu = this.fromMenu();
            if (menu) {
                focus = menu.moveToItemWithName("Sign In");
                if (focus) {
                    return(true);
                }
                return (false);
            }
            return(false);
        }
        return(false);
    }

    // methods for Location

    // --------------------------------------------------------------------------------
    //      Function: setLocation
    //              Go back to main menu select Settings>iTunes Store and change
    //              location of iTunes Store.
    //      Parameters:
    //              location - string
    //      Returns:
    //              true  - Found item and selected it.
    //              false - Failed to get to item
    // --------------------------------------------------------------------------------

    itunesstore.setLocation = function setLocation(location) {
        var menu = this.goTo();
        var focus;
        if ( ! menu) {
            return(false);
        }

        focus = menu.moveToItemWithName("Location");
        if ( ! focus) {
            return(false);
        }

        if (focus.value() == location) {
            // already set
            return(true);
        }
        menu.selectIntoPage();

        var locationMenu = new ATVAPageListMenu("Location");
        if ( ! locationMenu.waitForPage()) {
            return (false);
        }

        if ( ! locationMenu.moveToItemWithNameAndSelect(location)) {
            return(false);
        }

        focus = locationMenu.itemWithFocus();
        while (focus.value() != 1) {
            atvaTarget.delay(1);
            focus = locationMenu.itemWithFocus();
        }

        locationMenu.menuOutOfPage();

        menu = this.fromMenu();
        if (menu) {
            focus = menu.moveToItemWithName("Location");
            if (focus) {
                if (focus.value() == location) {
                    return(true);
                }
                return(false);
            }
            return(false);
        }
        return(false);
    }

    // methods for Video Resolution

    // methods for HD Previews

    // methods for Sort Favorites

    // methods for iTunes Match

    // methods for Check For Rentals

    // methods for Stop Loading
}

