
#import "iTunesStore.js"

/**
 *       Function: itunesstoreTest_signInToAccount
 *           Try to sign in to the iTunes Store through Settings>iTunes Store>Sign In.
 *
 *           1) If already signed in with this account, passed.
 *           2) If never signed in, tried to signed.
 *           3) If signed in with another account, adds this account (becomes the current).
 *           4) If muliple accounts and this on is in the list, switches to it.
 *
 *           In the last case, the storePassword and storeSavePassword are ignored.
 *
 *           storeSavePassword determines if the password is stored. true indicated that
 *           it should be stored and later store purchases will not require it. In general,
 *           it is safer to not store the password in automated testing.
 *   
 *  \param storeAccount (string) - iTunes Store account
 *  \param storePassword (string) - iTunes Store password
 *  \param storeSavePassword (boolean) - should the password be stored
 *   
 *  \return 1 if successfully signed in, otherwise 0
 **/

function itunesstoreTest_signInToAccount() {
    if (this.argv.length < 3) {
        this.testError = "Account information not specified.";
        return this.testResult = 0;
    }
    var storeAccount = this.argv[0];
    var storePassword = this.argv[1];
    var storeSavePassword = false;
    if (this.argv[2].toUpperCase() == "TRUE") {
        storeSavePassword = true;
    }
    if ( ! itunesstore.loginAccount(storeAccount, storePassword, storeSavePassword)) {
        this.testError = "Fail to login to iTunes Store";
        return this.testResult = 0;
    }
    else {
        return this.testResult = 1;
    }
}

/**
 *       Function: itunesstoreTest_signOutOfAccount
 *           Try to sign out and remove account from iTunes Store through Settings>iTunes Store>Accounts.
 *
 *           1) If not signed in with account, fails.
 *           2) If signed in, selects account to remove. Fast user switch could leave the
 *              box with no account selected or if the account removed is not currently selected,
 *              the previous selected account should still be selected.
 *   
 *  \param storeAccount (string) - iTunes Store account
 *   
 *  \return 1 if successfully signed out, otherwise 0
 **/

function itunesstoreTest_signOutOfAccount() {
    if (this.argv.length < 1) {
        this.testError = "Account information not specified.";
        return this.testResult = 0;
    }
    var storeAccount = this.argv[0];
    if ( ! itunesstore.logoutAccount(storeAccount)) {
        this.testError = "Fail to log out of iTunes Store";
        return this.testResult = 0;
    }
    else {
        return this.testResult = 1;
    }
}
