
#import "../Settings.js"

// --------------------------------------------------------------------------------
//      Object: screensaver
//              screensaver is an ATVAApp object for interacting with the
//              Screen Saver appliance on Apple TV.
// --------------------------------------------------------------------------------

if (typeof screensaver == 'undefined') {
    screensaver = new ATVAApp("Screen Saver");
}

if (typeof screensaver != 'undefined') {
    screensaver._objectName = "screensaver";

    // overriding fromMenu(), and goTo() methods from base ATVAApp()
    screensaver.fromMenu = function fromMenu() {
        var menu = new ATVAPageListMenu(this._title);
        if ( ! menu.waitForPage()) {
            UIALogger.logError(this._objectName + ".fromMenu(): failed to waiting for " + this._title);
            return(undefined);
        }
        return(menu);
    }

    screensaver.goTo = function goTo() {
        if (settings.goToAndSelect(this._title)) {
            return(this.fromMenu());
        }
        UIALogger.logError(this._objectName + ".goTo(): failed to get to " + this._title);
        return(undefined);
    }

    // Override menuItemsWithValues, toggleMenuItemsAndValues and menuItemsDefaultValues data
    screensaver.menuItemsWithValues = [
        'Start After',
        'Show During Music'
    ];
    screensaver.toggleMenuItemsAndValues = {
        'Start After':['Never', '2 minutes', '5 minutes', '10 minutes', '15 minutes', '30 minutes'],
        'Show During Music':['No', 'Yes']
    };
    screensaver.convertStartAfterToSeconds = {
        'Never':-1,
        '2 minutes':120,
        '5 minutes':300,
        '10 minutes':600,
        '15 minutes':900,
        '30 minutes':1800
    };
    screensaver.menuItemsDefaultValues = {
        'Start After':'5 minutes',
        'Show During Music':'Yes'
    };

    // default screen saver

    screensaver.allScreenSavers = [
        'Random',
        'Cascade',
        'Flip-up',
        'Floating',
        'Holiday Mobile',
        'Origami',
        'Photo Mobile',
        'Photo Wall',
        'Reflections',
        'Scrapbook',
        'Shifting Tiles',
        'Shrinking Tiles',
        'Sliding Panels',
        'Snapshots',
        'Ken Burns',
        'Classic',
    ];

    screensaver.screenSaversWithOptions = [
        'Ken Burns',
        'Classic'
    ];

    screensaver.allMarimbaScreenSavers = [
        'Cascade',
        'Flip-up',
        'Holiday Mobile',
        'Origami',
        'Photo Mobile',
        'Photo Wall',
        'Reflections',
        'Scrapbook',
        'Shifting Tiles',
        'Shrinking Tiles',
        'Sliding Panels',
        'Snapshots'
    ];

    screensaver.setScreenSaver = function setScreenSaver(menu, item) {
        if (screensaver.allScreenSavers.indexOf(item) == -1) {
            UIALogger.logError(this._objectName + ".setScreenSaver(): unknown screen saver \"" + item + "\"");
            return(false);
        }

        if (screensaver.screenSaversWithOptions.indexOf(item) != -1) {
            UIALogger.logError(this._objectName + ".setScreenSaver(): cannot set this screen saver with this function \"" + item + "\"");
            return(false);
        }

        if ( ! menu) {
            UIALogger.logError(this._objectName + ".setScreenSaver(): no menu given, cannot continue");
            return(false);
        }

        if ( ! menu.moveToItemWithNameAndSelect(item)) {
            UIALogger.logError(this._objectName + ".setScreenSaver(): failed find screen saver in menu \"" + item + "\"");
            return(false);
        }

        // TODO: for these check items, value() doesn't return anything from focus (UIAXElement). Lets just assumed it worked for now.
        return(true);

        // OLD CODE, doesn't work
        var focus = menu.itemWithFocus();
        var timesCheck = 0;
        while ((timesCheck < 5) && (focus.value() != 1)) {
            atvaTarget.delay(1);
            focus = menu.itemWithFocus();
            ++timesCheck;
        }

        if (focus.value() == 1) {
            return(true);
        }
        else {
            UIALogger.logError(this._objectName + ".setScreenSaver(): failed to select screen saver in menu \"" + item + "\"");
            return(false);
        }
    }

    screensaver.goToAndSetScreenSaver = function goToAndSetScreenSaver(item) {
        return(this.setScreenSaver(this.goTo(), item));
    }

    screensaver.fromAndSetScreenSaver = function fromAndSetScreenSaver(item) {
        return(this.setScreenSaver(this.fromMenu(), item));
    }
}
