
#import "ScreenSaver.js"
#import "../../movies/Movies.js"

/**
 *       Function: screensaverTest_setScreenSaverStartMovieAndPause.
 *           Go to Settings>Screen Saver, set time out, select screen saver, let fire and run for time
 *   
 *  \param movieTitle (string) - screen saver name
 *  \param screenSaverName (string) - screen saver name
 *  \param startAfter (string) - Time out ("2 minutes", "5 minutes", ...)
 *  \param runTime (string) - time in seconds to run screen saver.
 *   
 *  \return 1 if found, otherwise 0
 **/

function screensaverTest_setScreenSaverStartMovieAndPause() {
    if (this.argv.length < 4) {
        this.testError = "Movie Title, Screen Saver name, start after time, and number of seconds for running not given";
        return this.testResult = 0;
    }
    var movieTitle = this.argv[0];
    var screenSaverName = this.argv[1];
    var startAfter = this.argv[2];
    var runTime = parseInt(this.argv[3]);

    UIALogger.logMessage("Trying to set screen saver time out to " + startAfter);
    if ( ! screensaver.goToAndSetValueForToggle('Start After', startAfter)) {
        this.testError = "Failed to set screen saver time out to " + startAfter;
        return this.testResult = 0;
    }

    if (screensaver.convertStartAfterToSeconds[startAfter] < 0) {
        this.testError = "Cannot use " + startAfter + " for test because the screen saver will never fire.";
        return this.testResult = 0;
    }

    UIALogger.logMessage("Setting screen saver to " + screenSaverName);
    if ( ! screensaver.fromAndSetScreenSaver(screenSaverName)) {
        this.testError = "Failed to set screen saver to " + screenSaverName;
        return this.testResult = 0;
    }

    var dp = movies.searchAndPlayMovie(movieTitle, false);

    if ( ! dp) {
        this.testError = "Fail to search for and play movie";
        return this.testResult = 0;
    }
    else {
        // pause movie
        dp.buttonSelect();

        UIALogger.logMessage("Waiting for screen saver to fire");
        atvaTarget.delay(screensaver.convertStartAfterToSeconds[startAfter] + 10);

        // Verify that screen saver is running.
        if ( ! appletv.isScreenSaverRunning()) {
            this.testError = "Screen saver never started";
            return this.testResult = 0;
        }

        UIALogger.logMessage("Letting screen saver run for " + runTime + " seconds");
        atvaTarget.delay(runTime);

        // Verify that screen saver is still running.
        if ( ! appletv.isScreenSaverRunning()) {
            // Currently, not failing.
            UIALogger.logMessage("Screen saver is not running at the end of the test");
            //this.testError = "Screen saver not running to finish test.";
            // return this.testResult = 0;
        }

        // dismissing the screen saver at the end of the test.
        dp.dismissScreenSaver();
        // allow time for screen saver to be dismissed 
        atvaTarget.delay(5);
        // menu out of movie
        dp.menuOutOfPage();

        if ( ! dp.waitForPage()) {
            this.testError = "Failed to get back to movies detail page";
            return this.testResult = 0;
        }

        return this.testResult = 1;
    }
}
