
#import "ScreenSaver.js"

/**
 *       Function: screensaverTest_setScreenSaverAndRun.
 *           Go to Settings>Screen Saver, set time out, select screen saver, let fire and run for time
 *   
 *  \param screenSaverName (string) - screen saver name
 *  \param startAfter (string) - Time out ("2 minutes", "5 minutes", ...)
 *  \param runTime (string) - time in seconds to run screen saver.
 *   
 *  \return 1 if found, otherwise 0
 **/

function screensaverTest_setScreenSaverAndRun() {
    if (this.argv.length < 3) {
        this.testError = "Screen Saver name, start after time, and number of seconds for running not given";
        return this.testResult = 0;
    }
    var screenSaverName = this.argv[0];
    var startAfter = this.argv[1];
    var runTime = parseInt(this.argv[2]);

    UIALogger.logMessage("Trying to set screen saver time out to " + startAfter);
    if ( ! screensaver.goToAndSetValueForToggle('Start After', startAfter)) {
        this.testError = "Failed to set screen saver time out to " + startAfter;
        return this.testResult = 0;
    }

    if (screensaver.convertStartAfterToSeconds[startAfter] < 0) {
        this.testError = "Cannot use " + startAfter + " for test because the screen saver will never fire.";
        return this.testResult = 0;
    }

    UIALogger.logMessage("Setting screen saver to " + screenSaverName);
    if ( ! screensaver.fromAndSetScreenSaver(screenSaverName)) {
        this.testError = "Failed to set screen saver to " + screenSaverName;
        return this.testResult = 0;
    }

    UIALogger.logMessage("Waiting for screen saver to fire");
    atvaTarget.delay(screensaver.convertStartAfterToSeconds[startAfter] + 10);

    // Verify that screen saver is running.
    if ( ! appletv.isScreenSaverRunning()) {
        this.testError = "Screen saver never started";
        return this.testResult = 0;
    }

    UIALogger.logMessage("Letting screen saver run for " + runTime + " seconds");
    atvaTarget.delay(runTime);

    // Verify that screen saver is still running.
    if ( ! appletv.isScreenSaverRunning()) {
        // Currently, not failing.
        UIALogger.logMessage("Screen saver is not running at the end of the test");
        //this.testError = "Screen saver not running to finish test.";
        // return this.testResult = 0;
    }

    // dismissing the screen saver at the end of the test
    appletv.dismissScreenSaver();

    return this.testResult = 1;
}

/**
 *       Function: screensaverTest_setScreenSaverAndRun.
 *           Go to Settings>Screen Saver, set time out, cycle through all screen savers,
 *           letting them fire and run for time
 *   
 *  \param startAfter (string) - Time out ("2 minutes", "5 minutes", ...)
 *  \param runTime (string) - time in seconds to run screen saver.
 *   
 *  \return 1 if found, otherwise 0
 **/

function screensaverTest_runAllScreenSavers() {
    if (this.argv.length < 2) {
        this.testError = "Start after time, and number of seconds for running not given";
        return this.testResult = 0;
    }
    var startAfter = this.argv[0];
    var runTime = parseInt(this.argv[1]);

    UIALogger.logMessage("Trying to set screen saver time out to " + startAfter);
    if ( ! screensaver.goToAndSetValueForToggle('Start After', startAfter)) {
        this.testError = "Failed to set screen saver time out to " + startAfter;
        return this.testResult = 0;
    }

    if (screensaver.convertStartAfterToSeconds[startAfter] < 0) {
        this.testError = "Cannot use " + startAfter + " for test because the screen saver will never fire.";
        return this.testResult = 0;
    }

    for (var i = 0; i < screensaver.allMarimbaScreenSavers.length; ++i) {
        UIALogger.logMessage("Setting screen saver to " + screensaver.allMarimbaScreenSavers[i]);
        if ( ! screensaver.fromAndSetScreenSaver(screensaver.allMarimbaScreenSavers[i])) {
            this.testError = "Failed to set screen saver to " + screensaver.allMarimbaScreenSavers[i];
            return this.testResult = 0;
        }

        UIALogger.logMessage("Waiting for screen saver to fire");
        atvaTarget.delay(screensaver.convertStartAfterToSeconds[startAfter] + 10);

        // Verify that screen saver is running.
        if ( ! appletv.isScreenSaverRunning()) {
            this.testError = "Screen saver never started";
            return this.testResult = 0;
        }

        UIALogger.logMessage("Letting screen saver run for " + runTime + " seconds");
        atvaTarget.delay(runTime);

        // Verify that screen saver is still running.
        if ( ! appletv.isScreenSaverRunning()) {
            // Currently, not failing.
            UIALogger.logMessage("Screen saver is not running at the end of the test");
            //this.testError = "Screen saver not running to finish test.";
            // return this.testResult = 0;
        }

        // dismissing the screen saver at the end of the test
        appletv.dismissScreenSaver();
    }

    return this.testResult = 1;
}

/**
 *       Function: screensaverTest_selectEachScreenSaver
 *           Cycle through all screen savers and select each one.
 *   
 *  \return 1 if found, otherwise 0
 **/

function screensaverTest_selectEachScreenSaver() {
    UIALogger.logMessage("Setting screen saver to " + screensaver.allMarimbaScreenSavers[0]);
    if ( ! screensaver.goToAndSetScreenSaver(screensaver.allMarimbaScreenSavers[0])) {
        this.testError = "Failed to set screen saver to " + screensaver.allMarimbaScreenSavers[0];
        return this.testResult = 0;
    }

    for (var i = 1; i < screensaver.allMarimbaScreenSavers.length; ++i) {
        UIALogger.logMessage("Setting screen saver to " + screensaver.allMarimbaScreenSavers[i]);
        if ( ! screensaver.fromAndSetScreenSaver(screensaver.allMarimbaScreenSavers[i])) {
            this.testError = "Failed to set screen saver to " + screensaver.allMarimbaScreenSavers[i];
            return this.testResult = 0;
        }
    }

    return this.testResult = 1;
}
